=======
History
=======

0.0.1 (2018-10-12)
------------------

* First release on PyPI.

0.0.2 (2018-10-13)
------------------

* Emit error messages.

0.0.3 (2018-10-16)
------------------

* Add line magic usage
* Change to load_ext pattern

0.0.4 (2018-10-16)
------------------

* Add argparse parsing for line and cell magic
* Add --temp-dir option to reduce clutter
* Add --file_prefix for organization

0.0.5 (2018-10-16)
------------------

* Add Quickstart notebook as a demo
* Remove print statements introduced during debugging

0.0.6 (2018-10-17)
------------------

* Add ITIKZ_TEMP_DIR environmental variable usage
* Add --implicit-pic

0.0.7 (2018-10-17)
------------------

* Add --scale arg
* Add --tikz-libraries
* Add --tex-packages
* Add --implicit-standalone

0.0.8 (2018-10-17)
------------------

* Add jinja2 templating
* Add jinja2 interpolated code debug printing

0.1.0 (2018-10-21)
------------------

* Add unit tests
* Fix cleanup bug

0.1.1 (2018-10-24)
------------------

* Add --rasterize option

0.1.2 (2018-10-25)
------------------

* Change default to only show the training 10 lines of an error
* Add --full-error option for full emitted error
